# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.27.18](https://github.com/conda/rattler/compare/rattler_index-v0.27.17...rattler_index-v0.27.18) - 2026-03-18

### Fixed

- set AWS_LC_SYS_CMAKE_BUILDER in pixi-build package configs ([#2241](https://github.com/conda/rattler/pull/2241))

### Other

- bump dependency versions ([#2237](https://github.com/conda/rattler/pull/2237))

## [0.27.17](https://github.com/conda/rattler/compare/rattler_index-v0.27.16...rattler_index-v0.27.17) - 2026-03-16

### Fixed

- *(rattler_index)* Remove non-existent packages from repodata ([#2196](https://github.com/conda/rattler/pull/2196))

## [0.27.16](https://github.com/conda/rattler/compare/rattler_index-v0.27.15...rattler_index-v0.27.16) - 2026-02-25

### Other

- experimental repodata v3 ([#2093](https://github.com/conda/rattler/pull/2093))

## [0.27.15](https://github.com/conda/rattler/compare/rattler_index-v0.27.14...rattler_index-v0.27.15) - 2026-02-20

### Other

- updated the following local packages: rattler_conda_types, rattler_config, rattler_networking, rattler_package_streaming, rattler_s3

## [0.27.14](https://github.com/conda/rattler/compare/rattler_index-v0.27.13...rattler_index-v0.27.14) - 2026-02-19

### Other

- bump rust to 1.93.1 ([#2072](https://github.com/conda/rattler/pull/2072))
- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))

## [0.27.13](https://github.com/conda/rattler/compare/rattler_index-v0.27.12...rattler_index-v0.27.13) - 2026-02-10

### Other

- updated the following local packages: rattler_package_streaming

## [0.27.12](https://github.com/conda/rattler/compare/rattler_index-v0.27.11...rattler_index-v0.27.12) - 2026-02-04

### Other

- update Cargo.lock dependencies

## [0.27.11](https://github.com/conda/rattler/compare/rattler_index-v0.27.10...rattler_index-v0.27.11) - 2026-01-22

### Other

- update Cargo.lock dependencies

## [0.27.10](https://github.com/baszalmstra/rattler/compare/rattler_index-v0.27.9...rattler_index-v0.27.10) - 2026-01-22

### Fixed

- changelog

## [0.27.9](https://github.com/conda/rattler/compare/rattler_index-v0.27.8...rattler_index-v0.27.9) - 2026-01-22

### Added

- add support for `packages.whl` and wheel archives types ([#1988](https://github.com/conda/rattler/pull/1988))

### Fixed

- Fix error handling in write_repodata by removing anyhow::Error and adding a dedicated error type ([#1899](https://github.com/conda/rattler/pull/1899))

### Other

- add type for archive file name ([#1999](https://github.com/conda/rattler/pull/1999))
- Run `cargo clippy --fix` (from nightly) ([#1992](https://github.com/conda/rattler/pull/1992))
- Make s3 optional for rattler_index ([#1965](https://github.com/conda/rattler/pull/1965))

## [0.27.8](https://github.com/conda/rattler/compare/rattler_index-v0.27.7...rattler_index-v0.27.8) - 2025-12-18

### Fixed

- add if-not-exists check to prevent concurrency issues when initializing S3 channel ([#1915](https://github.com/conda/rattler/pull/1915))

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [0.27.7](https://github.com/conda/rattler/compare/rattler_index-v0.27.6...rattler_index-v0.27.7) - 2025-12-08

### Added

- add ensure_channel_initialized for fs and s3 channels ([#1906](https://github.com/conda/rattler/pull/1906))

## [0.27.6](https://github.com/conda/rattler/compare/rattler_index-v0.27.5...rattler_index-v0.27.6) - 2025-11-27

### Other

- update Cargo.lock dependencies

## [0.27.5](https://github.com/conda/rattler/compare/rattler_index-v0.27.4...rattler_index-v0.27.5) - 2025-11-25

### Other

- update Cargo.lock dependencies

## [0.27.4](https://github.com/conda/rattler/compare/rattler_index-v0.27.3...rattler_index-v0.27.4) - 2025-11-22

### Other

- updated the following local packages: rattler_conda_types, rattler_package_streaming, rattler_config, rattler_networking, rattler_s3

## [0.27.3](https://github.com/conda/rattler/compare/rattler_index-v0.27.2...rattler_index-v0.27.3) - 2025-11-20

### Other

- updated the following local packages: rattler_conda_types, rattler_config, rattler_networking, rattler_package_streaming, rattler_s3

## [0.27.2](https://github.com/conda/rattler/compare/rattler_index-v0.27.1...rattler_index-v0.27.2) - 2025-11-19

### Other

- update Cargo.lock dependencies

## [0.27.1](https://github.com/conda/rattler/compare/rattler_index-v0.27.0...rattler_index-v0.27.1) - 2025-11-13

### Added

- add cache control for repodata.json / zst and shard index ([#1796](https://github.com/conda/rattler/pull/1796))

## [0.27.0](https://github.com/conda/rattler/compare/rattler_index-v0.26.5...rattler_index-v0.27.0) - 2025-10-28

### Added

- make precondition checks configurable ([#1777](https://github.com/conda/rattler/pull/1777))

### Other

- Replace fxhash with ahash ([#1674](https://github.com/conda/rattler/pull/1674))

## [0.26.5](https://github.com/conda/rattler/compare/rattler_index-v0.26.4...rattler_index-v0.26.5) - 2025-10-25

### Other

- update Cargo.lock dependencies

## [0.26.4](https://github.com/conda/rattler/compare/rattler_index-v0.26.3...rattler_index-v0.26.4) - 2025-10-18

### Other

- updated the following local packages: rattler_conda_types, rattler_package_streaming, rattler_config, rattler_networking, rattler_s3

## [0.26.3](https://github.com/conda/rattler/compare/rattler_index-v0.26.2...rattler_index-v0.26.3) - 2025-10-17

### Other

- update Cargo.lock dependencies

## [0.26.2](https://github.com/conda/rattler/compare/rattler_index-v0.26.1...rattler_index-v0.26.2) - 2025-10-14

### Fixed

- retry policy for indexing operations ([#1745](https://github.com/conda/rattler/pull/1745))

## [0.26.1](https://github.com/conda/rattler/compare/rattler_index-v0.26.0...rattler_index-v0.26.1) - 2025-10-13

### Other

- updated the following local packages: rattler_networking, rattler_package_streaming, rattler_s3

## [0.26.0](https://github.com/conda/rattler/compare/rattler_index-v0.25.6...rattler_index-v0.26.0) - 2025-10-10

### Added

- detect concurrent s3 indexing ([#1716](https://github.com/conda/rattler/pull/1716))

## [0.25.6](https://github.com/conda/rattler/compare/rattler_index-v0.25.5...rattler_index-v0.25.6) - 2025-10-09

### Other

- update Cargo.lock dependencies

## [0.25.5](https://github.com/conda/rattler/compare/rattler_index-v0.25.4...rattler_index-v0.25.5) - 2025-10-07

### Other

- update Cargo.lock dependencies

## [0.25.4](https://github.com/conda/rattler/compare/rattler_index-v0.25.3...rattler_index-v0.25.4) - 2025-10-03

### Other

- updated the following local packages: rattler_conda_types, rattler_config, rattler_networking, rattler_package_streaming, rattler_s3

## [0.25.3](https://github.com/conda/rattler/compare/rattler_index-v0.25.2...rattler_index-v0.25.3) - 2025-09-30

### Other

- add LazyClient to late initialize the reqwest client ([#1687](https://github.com/conda/rattler/pull/1687))

## [0.25.2](https://github.com/conda/rattler/compare/rattler_index-v0.25.1...rattler_index-v0.25.2) - 2025-09-17

### Other

- update Cargo.lock dependencies

## [0.25.1](https://github.com/conda/rattler/compare/rattler_index-v0.25.0...rattler_index-v0.25.1) - 2025-09-05

### Other

- updated the following local packages: rattler_conda_types, rattler_config, rattler_networking, rattler_package_streaming, rattler_s3

## [0.25.0](https://github.com/conda/rattler/compare/rattler_index-v0.24.12...rattler_index-v0.25.0) - 2025-09-04

### Added

- derive default credentials from aws sdk ([#1629](https://github.com/conda/rattler/pull/1629))

## [0.24.12](https://github.com/conda/rattler/compare/rattler_index-v0.24.11...rattler_index-v0.24.12) - 2025-09-02

### Other

- update Cargo.lock dependencies

## [0.24.11](https://github.com/conda/rattler/compare/rattler_index-v0.24.10...rattler_index-v0.24.11) - 2025-08-28

### Other

- update Cargo.lock dependencies

## [0.24.10](https://github.com/conda/rattler/compare/rattler_index-v0.24.9...rattler_index-v0.24.10) - 2025-08-22

### Other

- update Cargo.lock dependencies

## [0.24.9](https://github.com/conda/rattler/compare/rattler_index-v0.24.8...rattler_index-v0.24.9) - 2025-08-15

### Other

- updated the following local packages: rattler_conda_types, rattler_config, rattler_networking, rattler_package_streaming

## [0.24.8](https://github.com/conda/rattler/compare/rattler_index-v0.24.7...rattler_index-v0.24.8) - 2025-08-12

### Other

- update Cargo.toml dependencies

## [0.24.7](https://github.com/conda/rattler/compare/rattler_index-v0.24.6...rattler_index-v0.24.7) - 2025-07-28

### Other

- updated the following local packages: rattler_package_streaming

## [0.24.6](https://github.com/conda/rattler/compare/rattler_index-v0.24.5...rattler_index-v0.24.6) - 2025-07-23

### Fixed

- indexing `extra-depends` ([#1546](https://github.com/conda/rattler/pull/1546))

## [0.24.5](https://github.com/conda/rattler/compare/rattler_index-v0.24.4...rattler_index-v0.24.5) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [0.24.4](https://github.com/conda/rattler/compare/rattler_index-v0.24.3...rattler_index-v0.24.4) - 2025-07-14

### Other

- updated the following local packages: rattler_conda_types, rattler_config, rattler_networking, rattler_package_streaming

## [0.24.3](https://github.com/conda/rattler/compare/rattler_index-v0.24.2...rattler_index-v0.24.3) - 2025-07-09

### Other

- update Cargo.lock dependencies

## [0.24.2](https://github.com/conda/rattler/compare/rattler_index-v0.24.1...rattler_index-v0.24.2) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.24.1](https://github.com/conda/rattler/compare/rattler_index-v0.24.0...rattler_index-v0.24.1) - 2025-06-26

### Other

- Fix typo ([#1479](https://github.com/conda/rattler/pull/1479))

## [0.23.3](https://github.com/conda/rattler/compare/rattler_index-v0.23.2...rattler_index-v0.23.3) - 2025-06-25

### Added

- *(rattler_index)* Use rattler_config ([#1466](https://github.com/conda/rattler/pull/1466))

## [0.23.2](https://github.com/conda/rattler/compare/rattler_index-v0.23.1...rattler_index-v0.23.2) - 2025-06-24

### Other

- update Cargo.lock dependencies

## [0.23.1](https://github.com/conda/rattler/compare/rattler_index-v0.23.0...rattler_index-v0.23.1) - 2025-06-23

### Added

- make rattler_networking system integration optional ([#1381](https://github.com/conda/rattler/pull/1381))

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.23.0](https://github.com/conda/rattler/compare/rattler_index-v0.22.7...rattler_index-v0.23.0) - 2025-05-23

### Added

- Sharded repodata, zst, add purls and run_exports support ([#1312](https://github.com/conda/rattler/pull/1312))

## [0.22.7](https://github.com/conda/rattler/compare/rattler_index-v0.22.6...rattler_index-v0.22.7) - 2025-05-16

### Added

- add purls to `IndexJson` ([#1303](https://github.com/conda/rattler/pull/1303))

## [0.22.6](https://github.com/conda/rattler/compare/rattler_index-v0.22.5...rattler_index-v0.22.6) - 2025-05-03

### Other

- lock workspace member dependencies ([#1279](https://github.com/conda/rattler/pull/1279))

## [0.22.5](https://github.com/conda/rattler/compare/rattler_index-v0.22.4...rattler_index-v0.22.5) - 2025-04-17

### Other

- update Cargo.lock dependencies

## [0.22.4](https://github.com/conda/rattler/compare/rattler_index-v0.22.3...rattler_index-v0.22.4) - 2025-04-10

### Other

- update Cargo.toml dependencies

## [0.22.3](https://github.com/conda/rattler/compare/rattler_index-v0.22.2...rattler_index-v0.22.3) - 2025-04-04

### Added

- add retry middleware to opendal operator ([#1207](https://github.com/conda/rattler/pull/1207))

### Fixed

- allow empty info key in repodata.json ([#1181](https://github.com/conda/rattler/pull/1181))
- don't clone package bytes in rattler-index ([#1175](https://github.com/conda/rattler/pull/1175))

## [0.22.2](https://github.com/conda/rattler/compare/rattler_index-v0.22.1...rattler_index-v0.22.2) - 2025-03-18

### Other

- update Cargo.lock dependencies

## [0.22.1](https://github.com/conda/rattler/compare/rattler_index-v0.22.0...rattler_index-v0.22.1) - 2025-03-14

### Other

- update Cargo.lock dependencies

## [0.22.0](https://github.com/conda/rattler/compare/rattler_index-v0.21.2...rattler_index-v0.22.0) - 2025-03-10

### Added

- Add support for repodata patching in rattler-index, fix silent failures ([#1129](https://github.com/conda/rattler/pull/1129))

## [0.21.2](https://github.com/conda/rattler/compare/rattler_index-v0.21.1...rattler_index-v0.21.2) - 2025-03-04

### Other

- update Cargo.lock dependencies

## [0.21.1](https://github.com/conda/rattler/compare/rattler_index-v0.21.0...rattler_index-v0.21.1) - 2025-02-28

### Other

- create reader from opendal buffer (#1123)

## [0.21.0](https://github.com/conda/rattler/compare/rattler_index-v0.20.13...rattler_index-v0.21.0) - 2025-02-27

### Added

- fix rattler-index name (#1114)
- Use `opendal` in `rattler-index` and add executable (#1076)

### Fixed

- make `menuinst` schema pub, hide utils, fix indexing for rattler-build (#1111)
- code review in rattler-index and test fix (#1109)

### Other

- remove tools/* features for rattler-index (#1112)

## [0.20.13](https://github.com/conda/rattler/compare/rattler_index-v0.20.12...rattler_index-v0.20.13) - 2025-02-25

### Other

- update Cargo.toml dependencies

## [0.20.12](https://github.com/conda/rattler/compare/rattler_index-v0.20.11...rattler_index-v0.20.12) - 2025-02-18

### Other

- update Cargo.toml dependencies

## [0.20.11](https://github.com/conda/rattler/compare/rattler_index-v0.20.10...rattler_index-v0.20.11) - 2025-02-06

### Other

- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.20.10](https://github.com/conda/rattler/compare/rattler_index-v0.20.9...rattler_index-v0.20.10) - 2025-02-06

### Other

- release (#1050)

## [0.20.9](https://github.com/conda/rattler/compare/rattler_index-v0.20.8...rattler_index-v0.20.9) - 2025-02-03

### Other

- updated the following local packages: rattler_conda_types

## [0.20.8](https://github.com/conda/rattler/compare/rattler_index-v0.20.7...rattler_index-v0.20.8) - 2025-01-23

### Added

- use tempfile and persist for repodata (#1031)

## [0.20.7](https://github.com/conda/rattler/compare/rattler_index-v0.20.6...rattler_index-v0.20.7) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [0.20.6](https://github.com/conda/rattler/compare/rattler_index-v0.20.5...rattler_index-v0.20.6) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [0.20.5](https://github.com/conda/rattler/compare/rattler_index-v0.20.4...rattler_index-v0.20.5) - 2025-01-08

### Other

- updated the following local packages: rattler_conda_types, rattler_digest, rattler_package_streaming

## [0.20.4](https://github.com/conda/rattler/compare/rattler_index-v0.20.3...rattler_index-v0.20.4) - 2024-12-20

### Other

- updated the following local packages: rattler_conda_types

## [0.20.3](https://github.com/conda/rattler/compare/rattler_index-v0.20.2...rattler_index-v0.20.3) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [0.20.2](https://github.com/conda/rattler/compare/rattler_index-v0.20.1...rattler_index-v0.20.2) - 2024-12-13

### Other

- updated the following local packages: rattler_conda_types

## [0.20.1](https://github.com/conda/rattler/compare/rattler_index-v0.20.0...rattler_index-v0.20.1) - 2024-12-12

### Other
- updated the following local packages: rattler_conda_types

## [0.20.0](https://github.com/conda/rattler/compare/rattler_index-v0.19.37...rattler_index-v0.20.0) - 2024-12-05

### Other

- release ([#967](https://github.com/conda/rattler/pull/967))

## [0.19.37](https://github.com/conda/rattler/compare/rattler_index-v0.19.36...rattler_index-v0.19.37) - 2024-11-30

### Other

- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.36](https://github.com/conda/rattler/compare/rattler_index-v0.19.35...rattler_index-v0.19.36) - 2024-11-18

### Other

- updated the following local packages: rattler_conda_types

## [0.19.35](https://github.com/conda/rattler/compare/rattler_index-v0.19.34...rattler_index-v0.19.35) - 2024-11-14

### Other

- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.34](https://github.com/conda/rattler/compare/rattler_index-v0.19.33...rattler_index-v0.19.34) - 2024-11-04

### Added

- use python_site_packages_path field when available for installing noarch: python packages, CEP-17 ([#909](https://github.com/conda/rattler/pull/909))

## [0.19.33](https://github.com/conda/rattler/compare/rattler_index-v0.19.32...rattler_index-v0.19.33) - 2024-10-21

### Fixed

- always index noarch even if folder already exists ([#907](https://github.com/conda/rattler/pull/907))

## [0.19.32](https://github.com/conda/rattler/compare/rattler_index-v0.19.31...rattler_index-v0.19.32) - 2024-10-07

### Other

- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.31](https://github.com/conda/rattler/compare/rattler_index-v0.19.30...rattler_index-v0.19.31) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [0.19.30](https://github.com/conda/rattler/compare/rattler_index-v0.19.29...rattler_index-v0.19.30) - 2024-10-01

### Other

- update Cargo.toml dependencies

## [0.19.29](https://github.com/conda/rattler/compare/rattler_index-v0.19.28...rattler_index-v0.19.29) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [0.19.28](https://github.com/conda/rattler/compare/rattler_index-v0.19.27...rattler_index-v0.19.28) - 2024-09-09

### Other

- updated the following local packages: rattler_conda_types

## [0.19.27](https://github.com/conda/rattler/compare/rattler_index-v0.19.26...rattler_index-v0.19.27) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.19.26](https://github.com/conda/rattler/compare/rattler_index-v0.19.25...rattler_index-v0.19.26) - 2024-09-03

### Other
- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.25](https://github.com/conda/rattler/compare/rattler_index-v0.19.24...rattler_index-v0.19.25) - 2024-09-02

### Other
- release ([#824](https://github.com/conda/rattler/pull/824))

## [0.19.24](https://github.com/conda/rattler/compare/rattler_index-v0.19.23...rattler_index-v0.19.24) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.19.23](https://github.com/baszalmstra/rattler/compare/rattler_index-v0.19.22...rattler_index-v0.19.23) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [0.19.22](https://github.com/baszalmstra/rattler/compare/rattler_index-v0.19.21...rattler_index-v0.19.22) - 2024-08-02

### Other
- mark some crates 1.0 ([#789](https://github.com/baszalmstra/rattler/pull/789))

## [0.19.21](https://github.com/conda/rattler/compare/rattler_index-v0.19.20...rattler_index-v0.19.21) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.19.20](https://github.com/conda/rattler/compare/rattler_index-v0.19.19...rattler_index-v0.19.20) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.19.19](https://github.com/conda/rattler/compare/rattler_index-v0.19.18...rattler_index-v0.19.19) - 2024-07-15

### Other
- updated the following local packages: rattler_conda_types, rattler_digest, rattler_package_streaming

## [0.19.18](https://github.com/conda/rattler/compare/rattler_index-v0.19.17...rattler_index-v0.19.18) - 2024-07-08

### Other
- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.17](https://github.com/conda/rattler/compare/rattler_index-v0.19.16...rattler_index-v0.19.17) - 2024-06-06

### Other
- make package_record_from_* functions public ([#726](https://github.com/conda/rattler/pull/726))

## [0.19.16](https://github.com/baszalmstra/rattler/compare/rattler_index-v0.19.15...rattler_index-v0.19.16) - 2024-06-04

### Other
- remove lfs ([#512](https://github.com/baszalmstra/rattler/pull/512))

## [0.19.15](https://github.com/conda/rattler/compare/rattler_index-v0.19.14...rattler_index-v0.19.15) - 2024-06-03

### Other
- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.14](https://github.com/conda/rattler/compare/rattler_index-v0.19.13...rattler_index-v0.19.14) - 2024-05-28

### Added
- add run exports to package data ([#671](https://github.com/conda/rattler/pull/671))

## [0.19.13](https://github.com/conda/rattler/compare/rattler_index-v0.19.12...rattler_index-v0.19.13) - 2024-05-27

### Added
- always store purls as a key in lock file ([#669](https://github.com/conda/rattler/pull/669))

## [0.19.12](https://github.com/conda/rattler/compare/rattler_index-v0.19.11...rattler_index-v0.19.12) - 2024-05-14

### Other
- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.11](https://github.com/conda/rattler/compare/rattler_index-v0.19.10...rattler_index-v0.19.11) - 2024-05-13

### Other
- updated the following local packages: rattler_conda_types, rattler_digest, rattler_package_streaming

## [0.19.10](https://github.com/conda/rattler/compare/rattler_index-v0.19.9...rattler_index-v0.19.10) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.19.9](https://github.com/conda/rattler/compare/rattler_index-v0.19.8...rattler_index-v0.19.9) - 2024-04-30

### Other
- release ([#625](https://github.com/conda/rattler/pull/625))

## [0.19.8](https://github.com/conda/rattler/compare/rattler_index-v0.19.7...rattler_index-v0.19.8) - 2024-04-25

### Other
- updated the following local packages: rattler_conda_types

## [0.19.7](https://github.com/conda/rattler/compare/rattler_index-v0.19.6...rattler_index-v0.19.7) - 2024-04-19

### Other
- update Cargo.toml dependencies

## [0.19.6](https://github.com/baszalmstra/rattler/compare/rattler_index-v0.19.5...rattler_index-v0.19.6) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.19.5](https://github.com/conda/rattler/compare/rattler_index-v0.19.4...rattler_index-v0.19.5) - 2024-03-30

### Other
- updated the following local packages: rattler_conda_types

## [0.19.4](https://github.com/conda/rattler/compare/rattler_index-v0.19.3...rattler_index-v0.19.4) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.19.3](https://github.com/conda/rattler/compare/rattler_index-v0.19.2...rattler_index-v0.19.3) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.2](https://github.com/conda/rattler/compare/rattler_index-v0.19.1...rattler_index-v0.19.2) - 2024-03-08

### Other
- updated the following local packages: rattler_conda_types, rattler_package_streaming

## [0.19.1](https://github.com/conda/rattler/compare/rattler_index-v0.19.0...rattler_index-v0.19.1) - 2024-03-06

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_index-v0.18.0...rattler_index-v0.19.0) - 2024-02-26

### Fixed
- Add indexed packages to the relevant section in the repodata ([#529](https://github.com/baszalmstra/rattler/pull/529))
